pub enum DriverMode {
Direct,
Forced,
}๐Deprecated: Driver mode should no longer used by generator implementations
Byte exhaustion strategy for the driver
Variants
Direct
๐Deprecated: Driver mode should no longer used by generator implementations
When the driver bytes are exhausted, the driver will fail fill input bytes. This is useful for fuzz engines that want accurate mapping of inputs to coverage.
Forced
๐Deprecated: Driver mode should no longer used by generator implementations
When the driver bytes are exhausted, the driver will continue to fill input bytes with 0. This is useful for engines that want to maximize the amount of time spent executing tests.